==> haskell-gtk-strut-0.1.3.2-267-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-strut.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gtk-strut
version:              0.1.3.2
visibility:           public
id:                   gtk-strut-0.1.3.2-7pg7UT0MgG0LN0RKbYqmWn
key:                  gtk-strut-0.1.3.2-7pg7UT0MgG0LN0RKbYqmWn
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-strut#readme
synopsis:             Library for creating strut windows with gi-gtk
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-strut#readme>

category:             System
abi:                  71f1fd027cf3c8fabc56bb5144681f89
exposed:              True
exposed-modules:      Graphics.UI.GIGtkStrut
hidden-modules:       Graphics.UI.EWMHStrut
import-dirs:          /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-strut
hs-libraries:         HSgtk-strut-0.1.3.2-7pg7UT0MgG0LN0RKbYqmWn
depends:
    base-4.17.2.1 data-default-0.7.1.2-CrFQ4dgXZ2xCKxCENN7hDD
    gi-gdk-3.0.28-3fwPu8uFVZb6BYwGRMOEdV
    gi-gtk-3.0.39-7VppoG2v1LRInWePEPacn
    hslogger-1.3.1.2-Y3KOsbvnm2KHxCwHzL0OJ text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gtk-strut/html/gtk-strut.haddock
haddock-html:         /usr/share/doc/haskell-gtk-strut/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk-strut-0.1.3.2-268-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-strut.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gtk-strut
version:              0.1.3.2
visibility:           public
id:                   gtk-strut-0.1.3.2-1uRPSBz6I1hL3wlNkWmnYL
key:                  gtk-strut-0.1.3.2-1uRPSBz6I1hL3wlNkWmnYL
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-strut#readme
synopsis:             Library for creating strut windows with gi-gtk
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-strut#readme>

category:             System
abi:                  adf9dec1440d9ed92ac292fa8a2658c9
exposed:              True
exposed-modules:      Graphics.UI.GIGtkStrut
hidden-modules:       Graphics.UI.EWMHStrut
import-dirs:          /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-strut
hs-libraries:         HSgtk-strut-0.1.3.2-1uRPSBz6I1hL3wlNkWmnYL
depends:
    base-4.17.2.1 data-default-0.7.1.2-7c115eFpvxq7Z5z0er1qPt
    gi-gdk-3.0.28-1X26bC7pZWw4P2pKxfXJVN
    gi-gtk-3.0.39-71wegpXxZREYUeF0azH5H
    hslogger-1.3.1.2-FC7vxUknfc9IVyZkGgrnoC text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gtk-strut/html/gtk-strut.haddock
haddock-html:         /usr/share/doc/haskell-gtk-strut/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
